==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/PRICINGSCHEDULEPARTCHARGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PRICINGSCHEDULEPARTCHARGEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PRICINGSCHEDULEPARTCHARGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICINGSCHEDULEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRICINGSCHEDULEPARTCHARGEID_Type", propOrder = {
    "pricingscheduleid",
    "classid"
})
public class PRICINGSCHEDULEPARTCHARGEID_Type {

    @XmlElement(name = "PRICINGSCHEDULEID", required = true)
    protected PRICINGSCHEDULEID_Type pricingscheduleid;
    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;

    /**
     * Gets the value of the pricingscheduleid property.
     * 
     * @return
     *     possible object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public PRICINGSCHEDULEID_Type getPRICINGSCHEDULEID() {
        return pricingscheduleid;
    }

    /**
     * Sets the value of the pricingscheduleid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public void setPRICINGSCHEDULEID(PRICINGSCHEDULEID_Type value) {
        this.pricingscheduleid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

}

==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/PRICINGSCHEDULEPARTCHARGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PRICINGSCHEDULEPARTCHARGEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PRICINGSCHEDULEPARTCHARGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICINGSCHEDULEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PRICINGSCHEDULEPARTCHARGEID_Type", propOrder = {
    "pricingscheduleid",
    "classid"
})
public class PRICINGSCHEDULEPARTCHARGEID_Type {

    @XmlElement(name = "PRICINGSCHEDULEID", required = true)
    protected PRICINGSCHEDULEID_Type pricingscheduleid;
    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;

    /**
     * Obtient la valeur de la propriété pricingscheduleid.
     * 
     * @return
     *     possible object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public PRICINGSCHEDULEID_Type getPRICINGSCHEDULEID() {
        return pricingscheduleid;
    }

    /**
     * Définit la valeur de la propriété pricingscheduleid.
     * 
     * @param value
     *     allowed object is
     *     {@link PRICINGSCHEDULEID_Type }
     *     
     */
    public void setPRICINGSCHEDULEID(PRICINGSCHEDULEID_Type value) {
        this.pricingscheduleid = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

}
